@@ -51,6 +51,8 @@ class Rule(ABC):
     attributes_from_test_set = []
     attributes_from_train_set = []
 
+    fitted_if_has = "prediction"
+
     daughters = []
 
     @classmethod
@@ -366,12 +368,16 @@ class Rule(ABC):
             kw = {item: kw[item] for item in kw if item in expected_args}
             method(**kw)
 
-        if not self.activation_available:
-            raise ValueError("Must have fitted the rule before calling 'eval'")
-
         if recompute_activation:
             self.calc_activation(xs=xs)
             xs = None
+
+        if not self.activation_available:
+            raise ValueError(
+                "Must have fitted the rule before calling 'eval', or use 'recompute_activation=True' to recompute it"
+                " from given xs"
+            )
+
         if xs is not None:
             activation = self.evaluate_activation(xs)
         else:
