@@ -426,7 +426,7 @@ class RuleSet(ABC):
         xs: Optional[Union["pd.DataFrame", np.ndarray]]
         keep_new_activations: bool
             If True, activation vectgor and stacked activation vectors will be kept as ruleset's attribute and replace
-            the ones computed using the train set, if any. Will not change the activation vectors of the rules however.
+            the ones computed using the train set, if any. Will also change the activation vectors of the rules.
         kwargs
 
 
@@ -463,8 +463,7 @@ class RuleSet(ABC):
                 if keep_new_activations:
                     clean_activation = not self.stack_activation
                     self.stack_activation = True
-                    self.compute_stacked_activation(xs)
-                    self.compute_self_activation(xs)
+                    self.calc_activation(xs=xs)  # Will reset rules' activation vectors too
                     self.stack_activation = not clean_activation
                     stacked_activation = self.stacked_activations
                     activation = self._activation
@@ -528,7 +527,7 @@ class RuleSet(ABC):
                     if not self._rules[ir].good:
                         to_drop.append(self._rules[ir])
         else:
-            [r.eval(xs=xs, y=y, **kwargs) for r in self]
+            [r.eval(xs=xs, y=y, recompute_activation=keep_new_activations, **kwargs) for r in self]
             to_drop = [r for r in self if not r.good]
 
         if len(to_drop) > 0:
@@ -548,11 +547,14 @@ class RuleSet(ABC):
                 self.stacked_activations = None
                 self.compute_stacked_activation()
         # If not bad rules were dropped and stacked fit was not used, still compute self.activation since it has not
-        # been done  (needed to set self.coverage), but not stacked (useless)
+        # been done
         elif not self.__class__.STACKED_FIT:
             if self.remember_activation:
                 self._activation = None
                 self.compute_self_activation()
+            if self.stack_activation:
+                self._activation = None
+                self.compute_stacked_activation()
 
         return to_drop
 
@@ -644,7 +646,7 @@ class RuleSet(ABC):
     def evaluate_self_activation(self, xs: Optional[Union[np.ndarray, "pd.DataFrame"]] = None):
         """Computes the activation vector of self from its rules, using time-efficient Activation.multi_logical_or."""
         if len(self) == 0:
-            return Activation(np.array([]), optimize=self[0]._activation.optimize, to_file=self[0]._activation.to_file)
+            return Activation(np.array([]))
         if xs is not None:
             activations = [r.evaluate_activation(xs) for r in self]
             activations_available = True
@@ -883,6 +885,8 @@ class RuleSet(ABC):
                 continue
 
         rule._condition = HyperrectangleCondition(**condition_index)
+        if hasattr(rule, rule.__class__.fitted_if_has) and getattr(rule, rule.__class__.fitted_if_has) is not None:
+            rule._fitted = True
         return rule
 
     # noinspection PyUnresolvedReferences
